Enum Event
#[non_exhaustive]pub enum Event<'a> {
Frame {
width: u32,
height: u32,
offset_x: u32,
offset_y: u32,
buffer_flags: u32,
flags: WEnum<Flags>,
format: u32,
mod_high: u32,
mod_low: u32,
num_objects: u32,
},
Object {
index: u32,
fd: BorrowedFd<'a>,
size: u32,
offset: u32,
stride: u32,
plane_index: u32,
},
Ready {
tv_sec_hi: u32,
tv_sec_lo: u32,
tv_nsec: u32,
},
Cancel {
reason: WEnum<CancelReason>,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Frame
a frame description
Main event supplying the client with information about the frame. If the capture didn’t fail, this event is always emitted first before any other events.
This event is followed by a number of “object” as specified by the “num_objects” argument.
Fields
Object
an object description
Event which serves to supply the client with the file descriptors containing the data for each object.
After receiving this event, the client must always close the file descriptor as soon as they’re done with it and even if the frame fails.
Fields
fd: BorrowedFd<'a>fd of the current object
Ready
indicates frame is available for reading
This event is sent as soon as the frame is presented, indicating it is available for reading. This event includes the time at which presentation happened at.
The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples, each component being an unsigned 32-bit value. Whole seconds are in tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo, and the additional fractional part in tv_nsec as nanoseconds. Hence, for valid timestamps tv_nsec must be in [0, 999999999]. The seconds part may have an arbitrary offset at start.
After receiving this event, the client should destroy this object.
Fields
Cancel
indicates the frame is no longer valid
If the capture failed or if the frame is no longer valid after the “frame” event has been emitted, this event will be used to inform the client to scrap the frame.
If the failure is temporary, the client may capture again the same source. If the failure is permanent, any further attempts to capture the same source will fail again.
After receiving this event, the client should destroy this object.
Fields
reason: WEnum<CancelReason>indicates a reason for cancelling this frame capture
Implementations