Struct ZwlrExportDmabufFrameV1

pub struct ZwlrExportDmabufFrameV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
a DMA-BUF frame

This object represents a single DMA-BUF frame.

If the capture is successful, the compositor will first send a “frame” event, followed by one or several “object”. When the frame is available for readout, the “ready” event is sent.

If the capture failed, the “cancel” event is sent. This can happen anytime before the “ready” event.

Once either a “ready” or a “cancel” event is received, the client should destroy the frame. Once an “object” event is received, the client is responsible for closing the associated file descriptor.

All frames are read-only and may not be written into or altered.

See also the Request enum for this interface.

Implementations



impl ZwlrExportDmabufFrameV1

pub fn frame( &self, width: u32, height: u32, offset_x: u32, offset_y: u32, buffer_flags: u32, flags: Flags, format: u32, mod_high: u32, mod_low: u32, num_objects: u32, )

a frame description

Main event supplying the client with information about the frame. If the capture didn’t fail, this event is always emitted first before any other events.

This event is followed by a number of “object” as specified by the “num_objects” argument.

pub fn object( &self, index: u32, fd: BorrowedFd<'_>, size: u32, offset: u32, stride: u32, plane_index: u32, )

an object description

Event which serves to supply the client with the file descriptors containing the data for each object.

After receiving this event, the client must always close the file descriptor as soon as they’re done with it and even if the frame fails.

pub fn ready(&self, tv_sec_hi: u32, tv_sec_lo: u32, tv_nsec: u32)

indicates frame is available for reading

This event is sent as soon as the frame is presented, indicating it is available for reading. This event includes the time at which presentation happened at.

The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples, each component being an unsigned 32-bit value. Whole seconds are in tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo, and the additional fractional part in tv_nsec as nanoseconds. Hence, for valid timestamps tv_nsec must be in [0, 999999999]. The seconds part may have an arbitrary offset at start.

After receiving this event, the client should destroy this object.

pub fn cancel(&self, reason: CancelReason)

indicates the frame is no longer valid

If the capture failed or if the frame is no longer valid after the “frame” event has been emitted, this event will be used to inform the client to scrap the frame.

If the failure is temporary, the client may capture again the same source. If the failure is permanent, any further attempts to capture the same source will fail again.

After receiving this event, the client should destroy this object.